@@ -1,11 +1,13 @@
 import os
 import json
 import sys
+import time
 
 from .utils import Utils, DockerError, S3Error
 from threading import Timer
 
 STATUS_RUNNING = 'RUNNING'
+STATUS_ERROR_ETL_BLOCKED = 'ERROR_ETL_BLOCKED'
 STATUS_ERROR = 'ERROR'
 
 class ETLError(Exception):
@@ -78,13 +80,13 @@ class ScanRunner(object):
         try:
             headers = {"Content-Type": "application/json"}
             resp = http.post(Utils.SKEN_SERVER_BASE_URL +
-                             '/doETL', headers=headers, data=json.dumps(req))
+                             '/doETL', headers=headers, data=json.dumps(req), timeout=300)
             resp_text = resp.text
             result = resp.json()
 
             if not result['success']:
                 print(result['message'])
-                # retry one more time  to mark current running item to error
+                # retry one more time to mark current running item to error
                 if not cls.etl_retry and cls._mark_error_item():
                     cls.etl_retry = True
                     Timer(cls.timer_delay, cls.do_etl).start()
@@ -153,7 +155,10 @@ class ScanRunner(object):
     def run_scan(cls, scan_data):
         # run docker
         try:
-            print('Launching scanner %s ' % scan_data['scanner'])
+            if scan_data['status'] == STATUS_ERROR_ETL_BLOCKED:
+                Utils.etl_waiting_countdown()
+                scan_data['status'] = STATUS_RUNNING
+            print(('Launching scanner ' + scan_data['scanner']).ljust(50, ' '))
             output_file = cls.run_docker(scan_data)
             # upload file
             file_empty = False
@@ -188,7 +193,7 @@ class ScanRunner(object):
         # pick up the scan data in running status
         scan_data = None
         for item in cls.scan_data_items:
-            if item['status'] == STATUS_RUNNING:
+            if item['status'] == STATUS_RUNNING or item['status'] == STATUS_ERROR_ETL_BLOCKED:
                 scan_data = item
                 break
 
@@ -213,7 +218,7 @@ class ScanRunner(object):
         cls.app_id = req['appid']
         cls.api_id = req['apiid']
         cls.build_dir = req['buildDir']
-        Utils.create_skenoutput_folder(cls.build_dir + os.path.sep + 'skenoutput')
+        Utils.create_skenoutput_folder(cls.build_dir + 'skenoutput')
 
         cls.get_scan_data(req)
         if len(cls.scan_data_items) == 0:
@@ -223,7 +228,7 @@ class ScanRunner(object):
         # pick up the scan data in running status
         scan_data = None
         for item in cls.scan_data_items:
-            if item['status'] == STATUS_RUNNING:
+            if item['status'] == STATUS_RUNNING or item['status'] == STATUS_ERROR_ETL_BLOCKED:
                 scan_data = item
                 break
 
