@@ -15,6 +15,7 @@ from xml.dom.minidom import parse
 import requests
 import yaml
 import logging
+import math
 
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
@@ -36,6 +37,8 @@ class Utils(object):
 	minutes25 = 60*25
 	cloc_file = None
 	min_docker_version = 18.03
+	# if a scanner for an app id is executed too close in time, skencli must wait for 5 minutes
+	etl_waiting_threshold = 300
 
 	@classmethod
 	def get_retryable_http(cls):
@@ -182,7 +185,8 @@ class Utils(object):
 
 	@classmethod
 	def delete_skenoutput_folder(cls):
-		shutil.rmtree(cls.sken_output_foler)
+		if os.path.exists(cls.sken_output_foler):
+			shutil.rmtree(cls.sken_output_foler)
 
 	@classmethod
 	def save_stdout(cls, scanner, content):
@@ -471,3 +475,16 @@ class Utils(object):
 			return []
 
 		return list(dict.fromkeys(list_object))
+
+	@classmethod
+	def etl_waiting_countdown(cls):
+		count = cls.etl_waiting_threshold
+		while count > 0:
+			minute = str(int(math.floor(count/60))).zfill(2)
+			seconds = str(count % 60).zfill(2)
+			sys.stdout.write('Previous scan ETL is processing, wait for ' + minute + ':' + seconds)
+			sys.stdout.write("\r")
+			sys.stdout.flush()
+			count -= 1
+			time.sleep(1)
+
